aceti_maps
===========

* Python library to make an efficient use of data
* License: MIT
* Compatible With: python 3.0+

Develop API Usage
-----------------

available maps
- Alamillo
- Alamillo11x15
- Alamillo30x49

<pre>
<code>
>>>from aceti_maps import import_map
>>>base_matrix, lat_lon_map  = import_map("alamillo11x15")

</code>
</pre>